ProSHADE: ProSHADE_internal_maths_bicubicInterpolator Class Reference

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

ProSHADE_internal_maths_bicubicInterpolator Class Reference

This class takes 4 by 4 array of input point values and allows bicubic interpolation of any value between them. More...

`#include <ProSHADE_maths.hpp>`

## Detailed Description

This class takes 4 by 4 array of input point values and allows bicubic interpolation of any value between them.

This class provides a constructor, which takes a 4 by 4 matrix of values. These values signify a function f(x,y) values at equidistantly placed indices on a unit square. Once the constructor is finished, the function getValue() an be used to obtain the interpolated value of any position on this unit square.

The documentation for this class was generated from the following file:

- src/proshade/ProSHADE_maths.hpp